=======
PYCIMVP
=======

.. image:: https://travis-ci.com/slee124565/pycimvp.svg?branch=main
   :target: https://travis-ci.com/slee124565/pycimvp

.. image:: https://coveralls.io/repos/github/slee124565/pycimvp/badge.svg?branch=main
   :target: https://coveralls.io/github/slee124565/pycimvp?branch=main

.. image:: https://img.shields.io/hexpm/l/plug.svg
   :target: https://github.com/slee124565/pycimvp/blob/main/LICENSE

.. image:: https://img.shields.io/pypi/v/pycimvp.svg
   :target: https://pypi.org/project/pycimvp

A Python library project for TDD + CI.


Web resources
-------------

* **Documentation**: https://pycimvp.readthedocs.io/
* Source code on **GitHub**: https://github.com/slee124565/pycimvp
* Python package index (PyPI) with download: https://pypi.org/project/pycimvp/
